<?php
/**
 * Class definition file for the Point Of Marketing API objects
 *
 * Defines common methods for POM objects
 *
 * @package POMAPI
 * @author Jeremy Miller
 * @copyright 2015 Repeat Returns
 * @version 2.0.1
 * @since 2.0.0
 */
namespace POMAPI;

abstract class POM_Object {
  /**
  * Map any values passed to this object's fields.
  */
  public function __construct($fields) {
    foreach ($fields as $field=>$value) {
      if (isset($this->$field)) {
        $this->$field = $value;
      }
    }
  }
  /**
   * Convert to URL-encoded string
   * @return URL-encoded string
   */
  public function serialize() {
    $return = $pfx = '';
    foreach($this as $key=>$value) {
      if (is_array($value)) {
        foreach ($value as $val) {
          if (is_array($val)) {
            foreach ($val as $k=>$v) {
              if ($v == -1 || strlen($v) == 0) {
                continue;
              }
              $return .= $pfx . $key . '[][' . $k . ']=' . urlencode($v);
              $pfx = '&';
            }
          } else {
            if ($val == -1 || strlen($val) == 0) {
              continue;
            }
            $return .= $pfx . $key . '[]=' . urlencode($val);
            $pfx = '&';
          }
        }
      } else {
        if ($value == -1 || strlen($value) == 0) {
          continue;
        }
        $return .= $pfx . $key . '=' . urlencode($value);
        $pfx = '&';
      }
    }
    return $return;
  }
  /**
   * Format this record as an HTML table
   * @return The HTML <code>TABLE</code> markup.
   */
  public function toHtmlTable($title = '') {
    $return = '<table class="pom-record-table"><thead>';
    if (strlen($title) > 0) {
      $return .= '<tr><th colspan="2" class="pom-record-table-title">' . $title . '</th></tr>';
    }
    $return .= '<tr><th>Field</th><th>Value</th></tr></thead><tbody>';
    foreach($this as $key=>$value) {
      if (is_array($value)) {
        foreach ($value as $idx=>$val) {
          if ($val == -1) {
            $val = '';
          }
          $return .= '<tr><td>' . $key . ' #' . ($idx + 1) . '</td><td>' . htmlspecialchars($val) . '</td></tr>';
        }
      } else {
        if ($value == -1) {
          $value = '';
        }
        $return .= '<tr><td>' . $key . '</td><td>' . htmlspecialchars($value) . '</td></tr>';
      }
    }
    return $return . '</tbody></table>';
  }
}